# Sendgrid Notification Library
## For Covenir Integration
2024-01-23

## Install Package
```python
pip install CovenirBPO.projects.SendgridNotificationSystem
```

## Set an environment variable
Create a local environment variable on the machine that will be sending notifications:

| Key          | Value                 |
| :----------- | :-------------------- |
| SENDGRID_API | Your Sendgrid API key |